@@ -35,20 +35,17 @@ fn main() {
         #[cfg(unix)]
         if let Err(err) = unixshell::shell(opt_host, opt_port, opts.rshell.unwrap()) {
             utils::print_error(err);
-            //println!("{:?}", err.kind());
-
-            //ConnectionRefused
-            //InvalidInput
-            //NotFound
         }
         return;
     }
     
     // Listen mode
     else if opts.listen_mode {
+
         let opts = utils::Opts {
             host: opt_host,
             port: opt_port,
+            exec: opts.exec,
             transport: if opts.udp_mode {
                 utils::Protocol::Udp
             } else {
@@ -56,17 +53,16 @@ fn main() {
             },
             mode: if opts.history {
                 utils::Mode::History
-            } else {
+            } else if opts.local_history {
+                utils::Mode::LocalHistory
+            } 
+            else {
                 utils::Mode::Normal
             },
         };
 
         if let Err(err) = listener::listen(&opts) {
             utils::print_error(err);
-            //println!("{:?}", err.kind());
-
-            // InvalidInput
-            // PermissionDenied
             return;
         };
     }
